models/http_response library
Classes
-
HttpResponse<
T> -
Tis the type of the decoded response body (data). OmittingT(or usingdynamic) keeps backward-compatible behaviour.
T is the type of the decoded response body (data).
Omitting T (or using dynamic) keeps backward-compatible behaviour.