HttpResponse<T> class

T is the type of the decoded response body (data). Omitting T (or using dynamic) keeps backward-compatible behaviour.

Constructors

HttpResponse({int? statusCode, T? data, Map<String, List<String>> headers = const {}, String? statusMessage})
const

Properties

data → T?
Decoded response body.
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, List<String>>
Response headers.
final
isSuccess bool
Returns true for 2xx status codes.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final
statusMessage String?
Optional human-readable status message (e.g. "OK", "Not Found").
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited